==> qtjambi-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiWidgets/QItemDelegate_shell.h <==
#ifndef QITEMDELEGATE_SHELL_H
#define QITEMDELEGATE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <qtwidgets-config.h>
#if QT_CONFIG(itemviews)
#include <QtWidgets/qitemdelegate.h>
#endif //QT_CONFIG(itemviews)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/QVector>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qrect.h>
#include <QtCore/qregexp.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qevent.h>
#include <QtGui/qfont.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpalette.h>
#include <QtGui/qpixmap.h>
#if QT_CONFIG(itemviews)
#include <QtWidgets/qabstractitemdelegate.h>
#endif //QT_CONFIG(itemviews)
#if QT_CONFIG(itemviews)
#include <QtWidgets/qabstractitemview.h>
#endif //QT_CONFIG(itemviews)
#if QT_CONFIG(itemviews)
#include <QtWidgets/qitemeditorfactory.h>
#endif //QT_CONFIG(itemviews)
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(itemviews)

class QItemDelegate_shell : public QItemDelegate, public QtJambiShellInterface
{
public:
    QItemDelegate_shell(QObject* parent0 = nullptr);
    ~QItemDelegate_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QWidget* createEditor(QWidget* parent0, const QStyleOptionViewItem& option1, const QModelIndex& index2) const override;
    void customEvent(QEvent* event0) override;
    void destroyEditor(QWidget* editor0, const QModelIndex& index1) const override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void drawCheck(QPainter* painter0, const QStyleOptionViewItem& option1, const QRect& rect2, Qt::CheckState state3) const override;
    void drawDecoration(QPainter* painter0, const QStyleOptionViewItem& option1, const QRect& rect2, const QPixmap& pixmap3) const override;
    void drawDisplay(QPainter* painter0, const QStyleOptionViewItem& option1, const QRect& rect2, const QString& text3) const override;
    void drawFocus(QPainter* painter0, const QStyleOptionViewItem& option1, const QRect& rect2) const override;
    bool editorEvent(QEvent* event0, QAbstractItemModel* model1, const QStyleOptionViewItem& option2, const QModelIndex& index3) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* object0, QEvent* event1) override;
    bool helpEvent(QHelpEvent* event0, QAbstractItemView* view1, const QStyleOptionViewItem& option2, const QModelIndex& index3) override;
    void paint(QPainter* painter0, const QStyleOptionViewItem& option1, const QModelIndex& index2) const override;
    QVector<int> paintingRoles() const override;
    void setEditorData(QWidget* editor0, const QModelIndex& index1) const override;
    void setModelData(QWidget* editor0, QAbstractItemModel* model1, const QModelIndex& index2) const override;
    QSize sizeHint(const QStyleOptionViewItem& option0, const QModelIndex& index1) const override;
    void timerEvent(QTimerEvent* event0) override;
    void updateEditorGeometry(QWidget* editor0, const QStyleOptionViewItem& option1, const QModelIndex& index2) const override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QItemDelegate_access : public QItemDelegate
{
    jobject __qt_decoration_cref_QStyleOptionViewItem_cref_QVariant_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID option0, jobject variant1) const;
    jobject __qt_doCheck_cref_QStyleOptionViewItem_cref_QRect_cref_QVariant_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID option0, QtJambiNativeID bounding1, jobject variant2) const;
    void __qt_drawBackground_QPainter_ptr_cref_QStyleOptionViewItem_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0, QtJambiNativeID option1, QtJambiNativeID index2) const;
    jobject __qt_rect_cref_QStyleOptionViewItem_cref_QModelIndex_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID option0, QtJambiNativeID index1, jint role2) const;
    static jobject __qt_selectedPixmap_cref_QPixmap_cref_QPalette_bool(JNIEnv *__jni_env, QtJambiNativeID pixmap0, QtJambiNativeID palette1, jboolean enabled2);
    jobject __qt_setOptions_cref_QModelIndex_cref_QStyleOptionViewItem_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID index0, QtJambiNativeID option1) const;
    jobject __qt_textRectangle_QPainter_ptr_cref_QRect_cref_QFont_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0, QtJambiNativeID rect1, QtJambiNativeID font2, jstring text3) const;
    jobject __qt_createEditor_QWidget_ptr_cref_QStyleOptionViewItem_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0, QtJambiNativeID option1, QtJambiNativeID index2) const;
    void __qt_drawCheck_QPainter_ptr_cref_QStyleOptionViewItem_cref_QRect_Qt_CheckState_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0, QtJambiNativeID option1, QtJambiNativeID rect2, jint state3) const;
    void __qt_drawDecoration_QPainter_ptr_cref_QStyleOptionViewItem_cref_QRect_cref_QPixmap_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0, QtJambiNativeID option1, QtJambiNativeID rect2, QtJambiNativeID pixmap3) const;
    void __qt_drawDisplay_QPainter_ptr_cref_QStyleOptionViewItem_cref_QRect_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0, QtJambiNativeID option1, QtJambiNativeID rect2, jstring text3) const;
    void __qt_drawFocus_QPainter_ptr_cref_QStyleOptionViewItem_cref_QRect_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0, QtJambiNativeID option1, QtJambiNativeID rect2) const;
    jboolean __qt_editorEvent_QEvent_ptr_QAbstractItemModel_ptr_cref_QStyleOptionViewItem_cref_QModelIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0, QtJambiNativeID model1, QtJambiNativeID option2, QtJambiNativeID index3);
    jboolean __qt_eventFilter_QObject_ptr_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID object0, QtJambiNativeID event1);
    void __qt_paint_QPainter_ptr_cref_QStyleOptionViewItem_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0, QtJambiNativeID option1, QtJambiNativeID index2) const;
    void __qt_setEditorData_QWidget_ptr_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID editor0, QtJambiNativeID index1) const;
    void __qt_setModelData_QWidget_ptr_QAbstractItemModel_ptr_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID editor0, QtJambiNativeID model1, QtJambiNativeID index2) const;
    jobject __qt_sizeHint_cref_QStyleOptionViewItem_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID option0, QtJambiNativeID index1) const;
    void __qt_updateEditorGeometry_QWidget_ptr_cref_QStyleOptionViewItem_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID editor0, QtJambiNativeID option1, QtJambiNativeID index2) const;
};

#endif // QT_CONFIG(itemviews)
#endif // QITEMDELEGATE_SHELL_H

==> qtjambi-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiWidgets/QItemDelegate_shell.h <==
#ifndef QITEMDELEGATE_SHELL_H
#define QITEMDELEGATE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtwidgets-config.h>
#if QT_CONFIG(itemviews)
#include <QtWidgets/qitemdelegate.h>
#endif //QT_CONFIG(itemviews)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qevent.h>
#include <QtGui/qfont.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpalette.h>
#include <QtGui/qpixmap.h>
#if QT_CONFIG(itemviews)
#include <QtWidgets/qabstractitemdelegate.h>
#endif //QT_CONFIG(itemviews)
#if QT_CONFIG(itemviews)
#include <QtWidgets/qabstractitemview.h>
#endif //QT_CONFIG(itemviews)
#if QT_CONFIG(itemviews)
#include <QtWidgets/qitemeditorfactory.h>
#endif //QT_CONFIG(itemviews)
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(itemviews)

class QItemDelegate_shell : public QItemDelegate, public QtJambiShellInterface
{
public:
    QItemDelegate_shell(QObject* parent0 = nullptr);
    ~QItemDelegate_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QItemDelegate_mshell;
    friend class QItemDelegate_oshell;
};


class QItemDelegate_mshell : public QItemDelegate_shell
{
public:
    using QItemDelegate_shell::QItemDelegate_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QItemDelegate_oshell : public QItemDelegate_mshell
{
public:
    using QItemDelegate_mshell::QItemDelegate_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QWidget* createEditor(QWidget* parent0, const QStyleOptionViewItem& option1, const QModelIndex& index2) const override;
    void customEvent(QEvent* event0) override;
    void destroyEditor(QWidget* editor0, const QModelIndex& index1) const override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void drawCheck(QPainter* painter0, const QStyleOptionViewItem& option1, const QRect& rect2, Qt::CheckState state3) const override;
    void drawDecoration(QPainter* painter0, const QStyleOptionViewItem& option1, const QRect& rect2, const QPixmap& pixmap3) const override;
    void drawDisplay(QPainter* painter0, const QStyleOptionViewItem& option1, const QRect& rect2, const QString& text3) const override;
    void drawFocus(QPainter* painter0, const QStyleOptionViewItem& option1, const QRect& rect2) const override;
    bool editorEvent(QEvent* event0, QAbstractItemModel* model1, const QStyleOptionViewItem& option2, const QModelIndex& index3) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* object0, QEvent* event1) override;
    bool helpEvent(QHelpEvent* event0, QAbstractItemView* view1, const QStyleOptionViewItem& option2, const QModelIndex& index3) override;
    void paint(QPainter* painter0, const QStyleOptionViewItem& option1, const QModelIndex& index2) const override;
    QList<int> paintingRoles() const override;
    void setEditorData(QWidget* editor0, const QModelIndex& index1) const override;
    void setModelData(QWidget* editor0, QAbstractItemModel* model1, const QModelIndex& index2) const override;
    QSize sizeHint(const QStyleOptionViewItem& option0, const QModelIndex& index1) const override;
    void timerEvent(QTimerEvent* event0) override;
    void updateEditorGeometry(QWidget* editor0, const QStyleOptionViewItem& option1, const QModelIndex& index2) const override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QItemDelegate_access : public QItemDelegate
{
    jobject __qt_decoration_cref_QStyleOptionViewItem_cref_QVariant_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID option0, jobject variant1) const;
    jobject __qt_doCheck_cref_QStyleOptionViewItem_cref_QRect_cref_QVariant_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID option0, QtJambiNativeID bounding1, jobject variant2) const;
    void __qt_drawBackground_QPainter_ptr_cref_QStyleOptionViewItem_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0, QtJambiNativeID option1, QtJambiNativeID index2) const;
    jobject __qt_rect_cref_QStyleOptionViewItem_cref_QModelIndex_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID option0, QtJambiNativeID index1, jint role2) const;
    static jobject __qt_selectedPixmap_cref_QPixmap_cref_QPalette_bool(JNIEnv *__jni_env, QtJambiNativeID pixmap0, QtJambiNativeID palette1, jboolean enabled2);
    jobject __qt_setOptions_cref_QModelIndex_cref_QStyleOptionViewItem_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID index0, QtJambiNativeID option1) const;
    jobject __qt_textRectangle_QPainter_ptr_cref_QRect_cref_QFont_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0, QtJambiNativeID rect1, QtJambiNativeID font2, jstring text3) const;
    jobject __qt_createEditor_QWidget_ptr_cref_QStyleOptionViewItem_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0, QtJambiNativeID option1, QtJambiNativeID index2) const;
    void __qt_drawCheck_QPainter_ptr_cref_QStyleOptionViewItem_cref_QRect_Qt_CheckState_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0, QtJambiNativeID option1, QtJambiNativeID rect2, jint state3) const;
    void __qt_drawDecoration_QPainter_ptr_cref_QStyleOptionViewItem_cref_QRect_cref_QPixmap_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0, QtJambiNativeID option1, QtJambiNativeID rect2, QtJambiNativeID pixmap3) const;
    void __qt_drawDisplay_QPainter_ptr_cref_QStyleOptionViewItem_cref_QRect_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0, QtJambiNativeID option1, QtJambiNativeID rect2, jstring text3) const;
    void __qt_drawFocus_QPainter_ptr_cref_QStyleOptionViewItem_cref_QRect_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0, QtJambiNativeID option1, QtJambiNativeID rect2) const;
    jboolean __qt_editorEvent_QEvent_ptr_QAbstractItemModel_ptr_cref_QStyleOptionViewItem_cref_QModelIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0, QtJambiNativeID model1, QtJambiNativeID option2, QtJambiNativeID index3);
    jboolean __qt_eventFilter_QObject_ptr_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID object0, QtJambiNativeID event1);
    void __qt_paint_QPainter_ptr_cref_QStyleOptionViewItem_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0, QtJambiNativeID option1, QtJambiNativeID index2) const;
    void __qt_setEditorData_QWidget_ptr_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID editor0, QtJambiNativeID index1) const;
    void __qt_setModelData_QWidget_ptr_QAbstractItemModel_ptr_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID editor0, QtJambiNativeID model1, QtJambiNativeID index2) const;
    jobject __qt_sizeHint_cref_QStyleOptionViewItem_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID option0, QtJambiNativeID index1) const;
    void __qt_updateEditorGeometry_QWidget_ptr_cref_QStyleOptionViewItem_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID editor0, QtJambiNativeID option1, QtJambiNativeID index2) const;
};

#endif // QT_CONFIG(itemviews)
#endif // QITEMDELEGATE_SHELL_H
